@@ -75,8 +75,7 @@ class GemBox:
             result.write("\n")
         
         # Gembox Messages
-        blah = [GemMail()]
-        for index, mail in enumerate(blah):
+        for index, mail in enumerate(self.Mails):
             # Metadata
             if len(mail.Senders) > 0:
                 result.write("Senders: ")
@@ -147,7 +146,7 @@ def parseGemBox(identifier, gembox_text = ""):
     inGboxMetadata = True # Very start of file is the metadata for the whole gembox
     inBody = False
     bodyStart = 0
-    currentGemMail = GemMail()
+    currentGemMail = GemMail(None)
     for index, line in enumerate(lines):
         if line.startswith("["): # Start of new message data
             if not inGboxMetadata:
